PatrolSingleTestEntry class

Represents a single test entry.

A single test entry is a collection of entries that belong to the same test. It starts with a TestEntry with status TestEntryStatus.start or TestEntryStatus.skip. Entry with skip status contains only one entry. Entry with start status contains also StepEntry and LogEntry entries. The last entry in the collection is a test entry with status TestEntryStatus.success or TestEntryStatus.failure.

Constructors

PatrolSingleTestEntry(TestEntry openingTestEntry)

Properties

closingTestEntry TestEntry?
getter/setter pair
executionTime Duration
The execution time of the test.
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the test.
no setter
nameWithPath String
The name of the test with the path.
no setter
openingTestEntry TestEntry
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status TestEntryStatus
The status of the test.
no setter

Methods

addEntry(Entry entry) → void
closeTest(TestEntry testEntry) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited