PatrolLogReader class
Constructors
-
PatrolLogReader({required DisposeScope scope, required StreamSubscription<
void> listenStdOut(void onData(String), {bool? cancelOnError, void onDone()?, Function? onError}), required void log(String), required String reportPath, required bool showFlutterLogs, required bool hideTestSteps, required bool clearTestSteps, bool hideTestLifecycle = false, void onLogEntry(Entry entry)?})
Properties
- clearTestSteps → bool
-
final
-
failedTests
→ List<
PatrolSingleTestEntry> -
Return list of failed tests.
no setter
- failedTestsCount → int
-
Returns the number of failed tests.
no setter
- failedTestsList → String
-
Returns
Stringthat have printed in bullet points name of failed tests with relative path to file that contains the test.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- hideTestLifecycle → bool
-
final
- hideTestSteps → bool
-
final
-
listenStdOut
→ StreamSubscription<
void> Function(void onData(String), {bool? cancelOnError, void onDone()?, Function? onError}) -
final
- log → void Function(String)
-
final
- onLogEntry → void Function(Entry entry)?
-
final
- reportPath → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showFlutterLogs → bool
-
final
- skippedTests → int
-
Returns the number of skipped tests.
no setter
- successfulTests → int
-
Returns the number of tests that passed.
no setter
- summary → String
-
Returns a summary of the test results. That contains:
no setter
- totalTests → int
-
Returns the total number of tests.
no setter
Methods
-
close(
) → void - Closes the stream subscription and the stream controller.
-
listen(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
String line) → void - Parse the line from the process output.
-
readEntries(
) → Future< void> - Read the entries from the stream and print them to the console.
-
startTimer(
) → void - Starts the timer measuring whole tests duration.
-
stopTimer(
) → void - Stops the timer measuring whole tests duration.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parseEntry(
String entryJson) → Entry - Parses patrol log entry from JSON.