failedTestsList property
String
get
failedTestsList
Returns String that have printed in bullet points name of failed tests
with relative path to file that contains the test.
Implementation
String get failedTestsList =>
failedTests.map((e) => ' - ${e.nameWithPath}').join('\n');